@@ -1,5 +1,5 @@
 #coding = utf-8
-__version__ = '0.4.1'
+__version__ = '0.4.3'
 
 import random
 from termcolor import colored, cprint
@@ -10,7 +10,7 @@ import os
 import json
 import getpass
 import uuid
-from datas import variables, loading, setGrid, getPlayers, notDone, isWinner 
+from Morpion.datas import variables, loading, setGrid, getPlayers, notDone, isWinner 
 
 
 
